@@ -8,7 +8,7 @@ SELIGIMUS="$(realpath "${HERE}/..")"
 cd "${SELIGIMUS}"
 
 source "${SELIGIMUS}/scripts/library/venv.sh"
-use_venv distribution_building frozen_build_requirements.txt
+use_venv "build" frozen_build_requirements.txt
 
 python3 setup.py sdist bdist_wheel
 
